@@ -767,7 +767,8 @@ def helm_set_replica_value(replicas_field_dict, release, namespace, helm_set_val
   if release in replicas_field_dict['replicas']:
     resources = replicas_field_dict['replicas'].get(release)
     for resource in resources:
-      cmd = "kubectl get -o=jsonpath='{.status.replicas}' -n " + namespace + " " + resource['type'] + " " + resource['resource']
+      #cmd = "kubectl get -o=jsonpath='{.status.replicas}' -n " + namespace + " " + resource['type'] + " " + resource['resource']
+      cmd = "kubectl get -o=jsonpath='{.spec.replicas}' -n " + namespace + " " + resource['type'] + " " + resource['resource']
       logger.debug("Run kubectl to get replicas [" + resource['resource'] + "]")
       replicas, err = exec_cmd(cmd)
       if err:
